#!/usr/bin/env bash
set -e

if [ "${USE_CLIENT_CERT}" == "true" ]; then
    SECURITY_DIR=/app/security
    CLIENT_CERT_FILE=${SECURITY_DIR}/ubs_client_cert.pem
    P12_FILE=${SECURITY_DIR}/ubs_client_cert.p12
    STORE_PASSWORD="$(echo $RANDOM | md5sum | head -c 25)"

    # Pull down the Client Certificate for UBS
    aws --region "${DEPLOY_REGION}" ssm get-parameter --name "/${LEGACY_ENV_NAME}/ubs_client_cert" --with-decryption | jq -r '.Parameter.Value' > "${CLIENT_CERT_FILE}"

    # Convert to P12 format for use as keystore.
    openssl pkcs12 -export -out ${P12_FILE} -in ${CLIENT_CERT_FILE} -inkey ${CLIENT_CERT_FILE} -password "pass:${STORE_PASSWORD}" -nomac

    exec java \
        -Djavax.net.ssl.keyStore=${P12_FILE} \
        -Djavax.net.ssl.keyStorePassword="${STORE_PASSWORD}" \
        -cp "$( cat /app/jib-classpath-file )" "$( cat /app/jib-main-class-file )"
else
    exec java -cp "$( cat /app/jib-classpath-file )" "$( cat /app/jib-main-class-file )"
fi
